@@ -136,7 +136,7 @@ class MigrationCommand(BaseCommand):
         old_pk_name = migration_step['old_pk_name']
         if old_pk_name not in source_fields:
             source_fields.insert(0, source_fields)
-        source_fields += [d['source'] for d in migration_fields if d['source'] not in source_fields]
+        source_fields += [d['source'] for d in migration_fields if d['source'] not in source_fields and not d.get('fake_field', False)]
         source_results = self.get_source_results(source_name, source_fields, limit)
         model = self.get_model(model_name)
         save_empty_object = migration_step.get('save_empty_object', True)
@@ -153,8 +153,7 @@ class MigrationCommand(BaseCommand):
                             continue  # only migrating objects with errors
                     except MigratedObject.DoesNotExist:
                         continue  # no migration means object was no migrated with error
-                elif obj is not None and self.only_new_objects and \
-                     MigratedObject.objects.object_migrations(obj).exists():
+                elif obj is not None and self.only_new_objects:
                     self.debug('%d. Skip "%s" object' % (i, obj))
                     continue  # no migration for non new objects
                 if obj is None:
@@ -275,9 +274,9 @@ class MigrationCommand(BaseCommand):
                 setter_name = field_mapping.get('setter', None)
                 if setter_name:
                     setter_func = getattr(self, setter_name)
-                    setter_func(obj, value)
+                    setter_func(obj, source_field, value)
                 elif field_name:
-                    self.setter(obj, field_name, value)
+                    self.setter(obj, source_field, field_name, value)
                 else:
                     raise ImproperlyConfigured('You have to define either "destination" or "setter" in migration_fields')
             except MigrationError, e:
@@ -285,13 +284,13 @@ class MigrationCommand(BaseCommand):
                 migration_mark.has_errors = True
                 migration_mark.errors += u'\n' + e.message
 
-    def getter(self, field_name, source_data):
+    def getter(self, source_field, source_data):
         """
         Get an attribute from source data
         """
-        return source_data[field_name]
+        return source_data[source_field]
 
-    def setter(self, obj, field_name, value):
+    def setter(self, obj, source_field, field_name, value):
         """
         Set an attribute to the migrated object
         """
